特集 文教·科学技術施策の動向と展開

# \-2019年度税制改正の概要

1\.教育資金の一括贈与に係る贈与税の非課税措置

の拡充

祖父母等から孫等に対して教育資金を一括贈与し<br>た場合の贈与税の非課税措置について、以下の見直<br>しを行った上で、適用期限を2年延長することが認<br>められました\(2021年3月31日まで\)。

○教育資金管理契約の終了年齢を、従来の30歳から、<br>在学中であることを条件に40歳まで引き上げる

<img src="figures/in_gallery3_p1_figure_0.png" width="200px"><br>
# 文部科学省大臣官房政策課

○23歳以上の孫等の教育資金の範囲を、学校等や教<br>育訓練給付の支給対象となる教育訓練に係る費用<br>に限定\(習い事等は対象外\)。

○贈与から3年以内に祖父母等が亡くなった場合、<br>孫等が23歳以上であれば贈与の残額を相続財産に<br>加算する\(在学中の場合を除く\)。

これにより、世代間の資産移転を通じた教育負担<br>の軽減を引き続き促進してまいります。

# 2\.特定の学資としての資金の貸付けに係る消費貸借<br>契約書の印紙税の非課税措置の延長

公益法人·学校法人等が実施する、経済的理由に<br>より修学困難な生徒又は学生に対する無利息等の条<br>件で行われる奨学金貸与事業の借用証書等に係る印<br>紙税の非課税措置について、その適用期限を3年延<br>長することが認められました\(2022年3月31日<br>まで\)。

これにより、引き続き、奨学金貸与に係る学生の<br>負担軽減を図ってまいります。

3\.試験研究を行った場合の法人税額等の特別控除<br>の延長及び拡充

民間企業の研究開発投資の維持·拡大に貢献し、<br>競争力を強化するため、民間企業が試験研究を行っ<br>た場合に法人税額等の控除を受けられる研究開発税<br>制について、以下の5点が認められました。

1ベンチャー企業の総額型の控除上限について法

人税額の40%\(現行:25%\)に引上げ

2オープンイノベーション型における研究開発型<br>ベンチャーとの共同研究における控除率を25%<br>\(現行:20%\)に引き上げるとともに控除上限<br>を10%\(現行:5%\)に引上げ

3総額型の控除率の上限を14%\(原則:10%\)と<br>する特例の適用期限を2年延長

<img src="figures/in_gallery3_p1_figure_1.png" width="200px"><br>
# \(その他\)

5大学等との共同研究に係る費用について、研究開発のプロジェクトマネジメント業務等を担うURA\(リサーチ·アドミニストレータ\)の人件費の<br>適用を明確化

4試験研究費の対売上比率が10%を超えた場合の控除上限の上乗せ措置の簡素化

9

文部科学広報 No\.233 2019年4月号
